.. role:: javascript(code)
   :language: javascript

========
Specimen
========

Body copy
---------

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras arcu
libero, mollis sed massa vel, *ornare viverra ex*. Mauris a ullamcorper
lacus. Nullam urna elit, malesuada eget finibus ut, ullamcorper ac
tortor. Vestibulum sodales pulvinar nisl, pharetra aliquet est. Quisque
volutpat erat ac nisi accumsan tempor.

**Sed suscipit**, orci non pretium pretium, quam mi gravida metus, vel
venenatis justo est condimentum diam. Maecenas non ornare justo. Nam a
ipsum eros. `Nulla aliquam <#>`__ orci sit amet nisl posuere malesuada.
Proin aliquet nulla velit, quis ultricies orci feugiat et.
``Ut tincidunt sollicitudin`` tincidunt. Aenean ullamcorper sit amet
nulla at interdum.

Headings
--------

The 3rd level
~~~~~~~~~~~~~

The 4th level
^^^^^^^^^^^^^

The 5th level
'''''''''''''

The 6th level


Headings with secondary text
----------------------------

The 3rd level with secondary text
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The 4th level with secondary text
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

The 5th level with secondary text
'''''''''''''''''''''''''''''''''

The 6th level with secondary text


Blockquotes
-----------

   Morbi eget dapibus felis. Vivamus venenatis porttitor tortor sit amet
   rutrum. Pellentesque aliquet quam enim, eu volutpat urna rutrum a.
   Nam vehicula nunc mauris, a ultricies libero efficitur sed. *Class
   aptent* taciti sociosqu ad litora torquent per conubia nostra, per
   inceptos himenaeos. Sed molestie imperdiet consectetur.

Blockquote nesting
~~~~~~~~~~~~~~~~~~

   **Sed aliquet**, neque at rutrum mollis, neque nisi tincidunt nibh,
   vitae faucibus lacus nunc at lacus. Nunc scelerisque, quam id cursus
   sodales, lorem `libero fermentum <#>`__ urna, ut efficitur elit
   ligula et nunc.

..

      Mauris dictum mi lacus, sit amet pellentesque urna vehicula
      fringilla. Ut sit amet placerat ante. Proin sed elementum nulla.
      Nunc vitae sem odio. Suspendisse ac eros arcu. Vivamus orci erat,
      volutpat a tempor et, rutrum. eu odio.

         ``Suspendisse rutrum facilisis risus``, eu posuere neque
         commodo a. Interdum et malesuada fames ac ante ipsum primis in
         faucibus. Sed nec leo bibendum, sodales mauris ut, tincidunt
         massa.

Other content blocks
~~~~~~~~~~~~~~~~~~~~

   Vestibulum vitae orci quis ante viverra ultricies ut eget turpis. Sed
   eu lectus dapibus, eleifend nulla varius, lobortis turpis. In ac
   hendrerit nisl, sit amet laoreet nibh.

      Praesent at :javascript:`return target`, sodales nibh vel, tempor
      felis. Fusce vel lacinia lacus. Suspendisse rhoncus nunc non nisi
      iaculis ultrices. Donec consectetur mauris non neque imperdiet,
      eget volutpat libero.

   .. code-block:: javascript
      :emphasize-lines: 8

      var _extends = function(target) {
        for (var i = 1; i < arguments.length; i++) {
          var source = arguments[i];
          for (var key in source) {
            target[key] = source[key];
          }
        }
        return target;
      };


Lists
-----

Unordered lists
~~~~~~~~~~~~~~~

-  Sed sagittis eleifend rutrum. Donec vitae suscipit est. Nullam tempus
   tellus non sem sollicitudin, quis rutrum leo facilisis. Nulla tempor
   lobortis orci, at elementum urna sodales vitae. In in vehicula nulla,
   quis ornare libero.

   -  Duis mollis est eget nibh volutpat, fermentum aliquet dui mollis.
   -  Nam vulputate tincidunt fringilla.
   -  Nullam dignissim ultrices urna non auctor.

-  Aliquam metus eros, pretium sed nulla venenatis, faucibus auctor ex.
   Proin ut eros sed sapien ullamcorper consequat. Nunc ligula ante,
   fringilla at aliquam ac, aliquet sed mauris.

-  Nulla et rhoncus turpis. Mauris ultricies elementum leo. Duis
   efficitur accumsan nibh eu mattis. Vivamus tempus velit eros,
   porttitor placerat nibh lacinia sed. Aenean in finibus diam.

Ordered lists
~~~~~~~~~~~~~

1. Integer vehicula feugiat magna, a mollis tellus. Nam mollis ex ante,
   quis elementum eros tempor rutrum. Aenean efficitur lobortis lacinia.
   Nulla consectetur feugiat sodales.

2. Cum sociis natoque penatibus et magnis dis parturient montes,
   nascetur ridiculus mus. Aliquam ornare feugiat quam et egestas. Nunc
   id erat et quam pellentesque lacinia eu vel odio.

   1. Vivamus venenatis porttitor tortor sit amet rutrum. Pellentesque
      aliquet quam enim, eu volutpat urna rutrum a. Nam vehicula nunc
      mauris, a ultricies libero efficitur sed.

      1. Mauris dictum mi lacus
      2. Ut sit amet placerat ante
      3. Suspendisse ac eros arcu

   2. Morbi eget dapibus felis. Vivamus venenatis porttitor tortor sit
      amet rutrum. Pellentesque aliquet quam enim, eu volutpat urna
      rutrum a. Sed aliquet, neque at rutrum mollis, neque nisi
      tincidunt nibh.

   3. Pellentesque eget :javascript:`var _extends` ornare tellus, ut gravida
      mi.

      .. code-block:: javascript
         :emphasize-lines: 1

         var _extends = function(target) {
           for (var i = 1; i < arguments.length; i++) {
             var source = arguments[i];
             for (var key in source) {
               target[key] = source[key];
             }
           }
           return target;
         };

3. Vivamus id mi enim. Integer id turpis sapien. Ut condimentum lobortis
   sagittis. Aliquam purus tellus, faucibus eget urna at, iaculis
   venenatis nulla. Vivamus a pharetra leo.

Definition lists
~~~~~~~~~~~~~~~~

Lorem ipsum dolor sit amet
   Sed sagittis eleifend rutrum. Donec vitae suscipit est. Nullam tempus
   tellus non sem sollicitudin, quis rutrum leo facilisis. Nulla tempor
   lobortis orci, at elementum urna sodales vitae. In in vehicula nulla.

   Duis mollis est eget nibh volutpat, fermentum aliquet dui mollis. Nam
   vulputate tincidunt fringilla. Nullam dignissim ultrices urna non
   auctor.

Cras arcu libero
   Aliquam metus eros, pretium sed nulla venenatis, faucibus auctor ex.
   Proin ut eros sed sapien ullamcorper consequat. Nunc ligula ante,
   fringilla at aliquam ac, aliquet sed mauris.

Code blocks
-----------

Inline
~~~~~~

Morbi eget ``dapibus felis``. Vivamus *``venenatis porttitor``* tortor
sit amet rutrum. Class aptent taciti sociosqu ad litora torquent per
conubia nostra, per inceptos himenaeos. |Pellentesque aliquet quam enim|_,
eu volutpat urna rutrum a.

Nam vehicula nunc ``:::js return target`` mauris, a ultricies libero
efficitur sed. Sed molestie imperdiet consectetur. Vivamus a pharetra
leo. Pellentesque eget ornare tellus, ut gravida mi. Fusce vel lacinia
lacus.

.. |Pellentesque aliquet quam enim| replace:: ``Pellentesque aliquet quam enim``
.. _Pellentesque aliquet quam enim: #

Listing
~~~~~~~

.. code-block:: javascript
   :emphasize-lines: 1,5,8

   var _extends = function(target) {
     for (var i = 1; i < arguments.length; i++) {
       var source = arguments[i];
       for (var key in source) {
         target[key] = source[key];
       }
     }
     return target;
   };

Horizontal rules
----------------

Aenean in finibus diam. Duis mollis est eget nibh volutpat, fermentum
aliquet dui mollis. Nam vulputate tincidunt fringilla. Nullam dignissim
ultrices urna non auctor.

--------------

Integer vehicula feugiat magna, a mollis tellus. Nam mollis ex ante,
quis elementum eros tempor rutrum. Aenean efficitur lobortis lacinia.
Nulla consectetur feugiat sodales.

Data tables
-----------

+--------------------------+-------------+------------+---------+------+-----+
| Sollicitudo / Pellentesi | consectetur | adipiscing | elit    | arcu | sed |
+==========================+=============+============+=========+======+=====+
| Vivamus a pharetra       | yes         | yes        | yes     | yes  | yes |
+--------------------------+-------------+------------+---------+------+-----+
| Ornare viverra ex        | yes         | yes        | yes     | yes  | yes |
+--------------------------+-------------+------------+---------+------+-----+
| Mauris a ullamcorper     | yes         | yes        | partial | yes  | yes |
+--------------------------+-------------+------------+---------+------+-----+
| Nullam urna elit         | yes         | yes        | yes     | yes  | yes |
+--------------------------+-------------+------------+---------+------+-----+
| Malesuada eget finibus   | yes         | yes        | yes     | yes  | yes |
+--------------------------+-------------+------------+---------+------+-----+
| Ullamcorper              | yes         | yes        | yes     | yes  | yes |
+--------------------------+-------------+------------+---------+------+-----+
| Vestibulum sodales       | yes         | -          | yes     | -    | yes |
+--------------------------+-------------+------------+---------+------+-----+
| Pulvinar nisl            | yes         | yes        | yes     | -    | -   |
+--------------------------+-------------+------------+---------+------+-----+
| Pharetra aliquet est     | yes         | yes        | yes     | yes  | yes |
+--------------------------+-------------+------------+---------+------+-----+
| Sed suscipit             | yes         | yes        | yes     | yes  | yes |
+--------------------------+-------------+------------+---------+------+-----+
| Orci non pretium         | yes         | partial    | -       | -    | -   |
+--------------------------+-------------+------------+---------+------+-----+

Sed sagittis eleifend rutrum. Donec vitae suscipit est. Nullam tempus
tellus non sem sollicitudin, quis rutrum leo facilisis. Nulla tempor
lobortis orci, at elementum urna sodales vitae. In in vehicula nulla,
quis ornare libero.

.. table::
    :align: center

    +---------------+---------+----------+
    | Left          | Center  | Right    |
    +===============+=========+==========+
    | Lorem         | *dolor* | ``amet`` |
    +---------------+---------+----------+
    | `ipsum <#>`__ | **sit** |          |
    +---------------+---------+----------+

Vestibulum vitae orci quis ante viverra ultricies ut eget turpis. Sed eu
lectus dapibus, eleifend nulla varius, lobortis turpis. In ac hendrerit
nisl, sit amet laoreet nibh.

.. table::
    :widths: 30 70

    +--------------+--------------------------------------------+
    | Table        | with colgroups (Pandoc)                    |
    +==============+============================================+
    | Lorem        | ipsum dolor sit amet.                      |
    +--------------+--------------------------------------------+
    | Sed sagittis | eleifend rutrum. Donec vitae suscipit est. |
    +--------------+--------------------------------------------+


Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus nec ipsum a
eros convallis facilisis eget at leo. Cras eu pulvinar eros, at accumsan dolor.
Ut gravida massa sed eros imperdiet fermentum. Donec ac diam ut lorem consequat
laoreet. Maecenas at ex diam. Phasellus tincidunt orci felis, nec commodo nisl
aliquet ac. Aenean eget ornare tellus. Nullam vel nunc quis nisi sodales
finibus in ut metus. Praesent ultrices mollis leo, auctor volutpat eros
consectetur in. Sed ac odio nisi. Cras aliquet ultrices nisl ac mattis. Nulla a
dui velit. Proin et ipsum quis metus auctor viverra. Proin suscipit massa quis
magna mattis, vel tincidunt quam tincidunt. Vestibulum nec feugiat metus, nec
scelerisque eros. Ut ultricies ornare aliquam.


Section II
----------

Proin ac mi tempor, ullamcorper ante at, sodales augue. Duis enim turpis,
volutpat eget consectetur id, facilisis vel nisl. Sed non leo aliquam, tempus
nisl eu, vestibulum enim. Suspendisse et leo imperdiet, pulvinar lacus sed,
commodo felis.

.. note::

  Praesent elit mi, pretium nec pellentesque eget, ultricies
  euismod turpis.


Sub section
~~~~~~~~~~~

In lobortis elementum tempus. Nam facilisis orci neque, eget vestibulum lectus
imperdiet sed. Aenean ac eros sollicitudin, accumsan turpis ac, faucibus arcu.


Section III
-----------

Donec sodales, velit ac sagittis fermentum, metus ante pharetra ex, ac eleifend
erat ligula in lacus. Donec tincidunt urna est, non mollis turpis lacinia sit
amet. Duis ac facilisis libero, ut interdum nibh. Sed rutrum dapibus pharetra.
Ut ac luctus nisi, vitae volutpat arcu. Vivamus venenatis eu nibh ut
consectetur. Cras tincidunt dui nisi, et facilisis eros feugiat nec.

Fusce ante:

- libero
- consequat quis facilisis id
- sollicitudin et nisl.

Aliquam diam mi, vulputate nec posuere id, consequat id elit. Ut feugiat lectus
quam, sed aliquet augue placerat nec. Sed volutpat leo ac condimentum
ullamcorper. Vivamus eleifend magna tellus, sit amet porta nunc ultrices eget.
Nullam id laoreet ex. Nam ultricies, ante et molestie mollis, magna sem porta
libero, sed molestie neque risus ut purus. Ut tellus sapien, auctor a lacus eu,
iaculis congue ex.

Duis et nisi a odio **scelerisque** sodales ac ut sapien. Ut eleifend blandit
velit luctus euismod. Curabitur at pulvinar mi. Cras molestie lorem non accumsan
gravida. Sed vulputate, ligula ut tincidunt congue, metus risus luctus lacus,
sed rhoncus ligula turpis non erat. Phasellus est est, *sollicitudin ut*
elementum vel, placerat in orci. Proin molestie posuere dolor sit amet
convallis. Donec id urna vel lacus ultrices pulvinar sit amet id metus. Donec
in venenatis ante. Nam eu rhoncus leo. Quisque posuere, leo vel porttitor
malesuada, nisi urna dignissim justo, vel consectetur purus elit in mauris.
Vestibulum lectus arcu, varius ut ligula quis, viverra gravida sem.

.. warning::

    Pellentesque in enim leo.

Images
------

Default Alignment
~~~~~~~~~~~~~~~~~
.. rst-example::

   .. image:: desert-flower.jpg
      :alt: Default image

Center Alignment
~~~~~~~~~~~~~~~~
.. rst-example::

   .. image:: desert-flower.jpg
      :alt: Centered Image, 80% scale
      :scale: 80%
      :align: center

Right Alignment
~~~~~~~~~~~~~~~
.. rst-example::

   .. image:: desert-flower.jpg
      :alt: Right Image, 60% scale
      :scale: 60%
      :align: right

Math again
----------

This serves as a test when using the ``navigation.instant`` feature and
switching between two pages with math.

.. math::

   (a + b)^2 = a^2 + 2ab + b^2

   (a - b)^2 = a^2 - 2ab + b^2
